@@ -553,7 +553,7 @@ class CustomerCategoryTree(ModelSQL, ModelView):
         pool = Pool()
         Company = pool.get('company.company')
         company = Transaction().context.get('company')
-        if company:
+        if company is not None and company >= 0:
             return Company(company).currency.id
 
 
@@ -800,7 +800,7 @@ class ProductCategoryTree(ModelSQL, ModelView):
         pool = Pool()
         Company = pool.get('company.company')
         company = Transaction().context.get('company')
-        if company:
+        if company is not None and company >= 0:
             return Company(company).currency.id
 
 
@@ -927,7 +927,7 @@ class RegionTree(ModelSQL, ModelView):
         pool = Pool()
         Company = pool.get('company.company')
         company = Transaction().context.get('company')
-        if company:
+        if company is not None and company >= 0:
             return Company(company).currency.id
 
 
